#!/usr/bin/perl
# Shows current, overdue, and advance todos for todo.sh
# Written by Craig Maloney
# (c) 2009 Craig Maloney
# Released under GPL v2 or greater

use Date::Calc qw(Add_Delta_Days);
use Time::localtime;
use warnings;
use strict;

my $VERSION = '0.2';
my $ADVANCE_DAYS = 7;
my $PREVIOUS_DAYS = 21;
my $debug = 0;
my $TODO_PATH = '/home/craig/gtd/todo';
my $TODO_COMMAND = '/home/craig/bin/todo.py -p ls ';

print "Current version: $version\n" if $debug ;

# Calculate the current date
my $tm = localtime;

# GREP for what is due on this date

my %date = ('month' => $tm->mon + 1,
            'day'   => $tm->mday,
            'year'  => $tm->year + 1900);

print "[ Due Today... ]\n";
&show_due_todo($date{'day'}, $date{'month'}, $date{'year'},0,'');

print "\n\n";

# Iterate and calculate items that are past due
print "[ Past-due items... ]\n";
for (my $i = $PREVIOUS_DAYS; $i>0; $i--) {
    print "$i\n" if $debug;
    my ($y2, $m2, $d2) = Add_Delta_Days($date{'year'}, $date{'month'}, $date{'day'}, $i * -1);
    &show_due_todo($d2,$m2,$y2,$i,'overdue');
}

print "\n\n";

# Iterate and calculate the next several days
print "[ Due $ADVANCE_DAYS days in advance... ]\n";
for (my $i = 1; $i<= $ADVANCE_DAYS; $i++) {
    my ($y2, $m2, $d2) = Add_Delta_Days($date{'year'}, $date{'month'}, $date{'day'}, $i);
    &show_due_todo($d2,$m2,$y2,$i,'until due');
}

print "\n\n";
print "Make it up... make it happen...\n";

exit;
sub show_due_todo {
    my ($day,$month,$year,$days,$message) = @_;
    my $command = sprintf ("$TODO_COMMAND %4d-%02d-%02d",$year,$month,$day);
    print $command."\n" if $debug;
    my $results = `$command`;
    foreach my $i (split "\n",$results) { 
        next if ($i =~ m/TODO: / || $i =~ m/--/);
        if ($i ne '') {
            print "$i";
        }
        if ($message eq '') {
            print "\n";
        } else {
            if ($days == 1) {
                print " ($days day $message)\n";
            } else {
                print " ($days days $message)\n";
            }
        }
    }
}

